





%global extra_gfortran_flags -fallow-argument-mismatch

ExclusiveArch:          x86_64 %{ix86} aarch64 %{arm} %{power64}

%global BLASLAPACK flexiblas
%global FFTW -L%{_libdir} -lfftw3 -lfftw3f
%global LIBXC -L%{_libdir} -lxc -lxcf90

Name:			elk
Version:		8.8.26
Release:    1%{?dist}
Summary:		An all-electron full-potential linearised augmented-plane wave code

License:		GPLv3+
URL:			http://elk.sourceforge.net/
Source0:		https://downloads.sourceforge.net/project/%{name}/%{name}-%{version}.tgz

BuildRequires:		patch
BuildRequires:		time

BuildRequires:		gcc-gfortran
BuildRequires:		%{BLASLAPACK}-devel



BuildRequires:		flexiblas-openblas-openmp
Requires:		flexiblas-openblas-openmp

BuildRequires:		fftw3-devel
BuildRequires:		libxc-devel

Requires:		%{name}-species = %{version}-%{release}


%global desc_base \
An all-electron full-potential linearised augmented-plane wave (FP-LAPW) code\
with many advanced features. Written originally at\
Karl-Franzens-Universität Graz as a milestone of the EXCITING EU Research and\
Training Network, the code is designed to be as simple as possible so that new\
developments in the field of density functional theory (DFT) can be added\
quickly and reliably.


%description
%{desc_base}


%package openmpi
Summary:		%{name} - openmpi version
BuildRequires:		openmpi-devel
Requires:		%{name}-species = %{version}-%{release}

%description openmpi
%{desc_base}

This package contains the openmpi version.


%package mpich
Summary:		%{name} - mpich version
BuildRequires:		mpich-devel
BuildRequires: make
Requires:		%{name}-species = %{version}-%{release}

%description mpich
%{desc_base}

This package contains the mpich version.


%package species
Summary:		%{name} - species files
Requires:		%{name}-common = %{version}-%{release}
BuildArch:		noarch

%description species
%{desc_base}

This package contains the species files.


%package common
Summary:		%{name} - common files

%description common
%{desc_base}

This package contains the common binaries.


%prep
%setup -q -n %{name}-%{version}



echo "SRC_MPI = mpi_stub.f90" > make.inc.common
echo "F90 = gfortran -fopenmp %{extra_gfortran_flags}" >> make.inc.common
echo "F77 = gfortran -fopenmp %{extra_gfortran_flags}" >> make.inc.common
echo "F90_OPTS = -I%{_fmoddir} %{optflags}" >> make.inc.common
echo "F77_OPTS = \$(F90_OPTS)" >> make.inc.common
echo "AR = ar" >> make.inc.common

echo "SRC_MKL = mkl_stub.f90" >> make.inc.common
echo "SRC_BLIS = blis_stub.f90" >> make.inc.common
echo "SRC_W90S = w90_stub.f90" >> make.inc.common

echo "F90_LIB = -L%{_libdir} -l%{BLASLAPACK} %{FFTW}" >> make.inc.common
echo "SRC_FFT = zfftifc_fftw.f90 cfftifc_fftw.f90" >> make.inc.common
echo "LIB_LIBXC = %LIBXC" >> make.inc.common
echo "SRC_LIBXC = libxcf90.f90 libxcifc.f90" >> make.inc.common


sed -i "s/blas lapack fft elk/elk/" src/Makefile
sed -i "s/erf.f90//" src/Makefile
sed -i "s/,erf//" src/stheta_mp.f90

rm -rf src/LAPACK src/BLAS src/fftlib
rm -f src/libxc_funcs.f90 src/libxc.f90
rm -f src/erf.f90


%build

mv src src.orig


%global dobuild() \
cp -p make.inc.common make.inc&& \
%{__sed} -i "s|F90 =.*|F90 = mpif90 -fopenmp %{extra_gfortran_flags}|" make.inc&& \
%{__sed} -i "s|F77 =.*|F77 = mpif77 -fopenmp %{extra_gfortran_flags}|" make.inc&& \
%{__sed} -i "s|F90_OPTS =|F90_OPTS = -I\${MPI_FORTRAN_MOD_DIR}|" make.inc&& \
echo "SRC_MPI =" >> make.inc&&\
cat make.inc&& \
cp -p make.inc make.inc$MPI_SUFFIX&& \
%{__make}&& \
mv src/%{name} %{name}$MPI_SUFFIX&& \
%{__make} clean


export MPI_SUFFIX=_openmp
cp -rp src.orig src
cp -p make.inc.common make.inc&& \
cat make.inc&& \
cp -p make.inc make.inc$MPI_SUFFIX&& \
%{__make}&& \
mv src/%{name} .&& \
mv src/eos/eos elk-eos&& \
mv src/spacegroup/spacegroup elk-spacegroup&& \
%{__make} clean&& \
rm -rf src


cp -rp src.orig src
%{_openmpi_load}
%dobuild
%{_openmpi_unload}
rm -rf src

cp -rp src.orig src

%{_mpich_load}
%dobuild
%{_mpich_unload}



%install
mkdir -p %{buildroot}%{_sysconfdir}


%global doinstall() \
mkdir -p %{buildroot}/$MPI_BIN&& \
install -p -m 755 %{name}$MPI_SUFFIX %{buildroot}/$MPI_BIN/%{name}_binary$MPI_SUFFIX&& \
echo '#!/bin/bash' >  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
echo 'export FLEXIBLAS=openblas-openmp' >>  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
echo 'export OMP_NUM_THREADS=1' >>  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
echo -n "%{name}_binary$MPI_SUFFIX " >>  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
echo '"$@"' >>  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
chmod 755  %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX&& \
cat %{buildroot}/$MPI_BIN/%{name}$MPI_SUFFIX



mkdir -p %{buildroot}%{_bindir}
install -p -m 755 %{name} elk-eos elk-spacegroup %{buildroot}%{_bindir}


%{_openmpi_load}
%doinstall
%{_openmpi_unload}


%{_mpich_load}
%doinstall
%{_mpich_unload}

mkdir -p %{buildroot}%{_datadir}/%{name}


cp -rp species %{buildroot}%{_datadir}/%{name}
cp -rp make.inc* %{buildroot}%{_datadir}/%{name}
cp -rp tests tests-libxc examples %{buildroot}%{_datadir}/%{name}


%check



%files
%{_bindir}/%{name}


%files common
%doc COPYING README
%{_bindir}/elk-eos
%{_bindir}/elk-spacegroup
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/species


%files species
%{_datadir}/%{name}/species


%files openmpi
%{_libdir}/openmpi%{?_opt_cc_suffix}/bin/%{name}_binary_openmpi
%{_libdir}/openmpi%{?_opt_cc_suffix}/bin/%{name}_openmpi


%files mpich
%{_libdir}/mpich%{?_opt_cc_suffix}/bin/%{name}_binary_mpich
%{_libdir}/mpich%{?_opt_cc_suffix}/bin/%{name}_mpich


%changelog
* Wed Aug 14 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.8.26-1
- initial build
